@@ -184,14 +184,14 @@ lsp_create_grid = function(x_crs, x_bb, x_delta_row, x_delta_col, window_shift){
 #' library(stars)
 #' library(terra)
 #' landform = read_stars(system.file("raster/landforms.tif", package = "motif"))
-#' plot(landform)
+#' #plot(landform)
 #' landform_lsp = lsp_add_terra(landform, window = 100)
-#' plot(landform_lsp)
+#' #plot(landform_lsp)
 #'
-#' lc_cove = lsp_signature(landform, type = "cove", window = 200, normalization = "pdf")
-#' lc_cove_lsp = lsp_add_terra(lc_cove)
-#' plot(lc_cove_lsp)
-#' plot(lc_cove_lsp["na_prop"])
+#' #lc_cove = lsp_signature(landform, type = "cove", window = 200, normalization = "pdf")
+#' #lc_cove_lsp = lsp_add_terra(lc_cove)
+#' #plot(lc_cove_lsp)
+#' #plot(lc_cove_lsp["na_prop"])
 #'
 #' @export
 lsp_add_terra = function(x = NULL, window = NULL){
@@ -199,7 +199,9 @@ lsp_add_terra = function(x = NULL, window = NULL){
     stop("package terra required, please install it first") # nocov
   }
   output = lsp_add_stars(x = x, window = window)
-  output = st_as_terra2(output)
+  output_names = names(output)
+  output = terra::rast(output)
+  names(output) = output_names
   return(output)
 }
 
@@ -254,6 +256,9 @@ lsp_add_sf = function(x = NULL, window = NULL) UseMethod("lsp_add_sf")
 lsp_add_sf.default = function(x = NULL, window = NULL){
 
   if (is.numeric(window) && window != 0){
+    if (inherits(x, "SpatRaster")){
+      x = stars::st_as_stars(x)
+    }
     x_nrow = nrow(x)
     x_ncol = ncol(x)
 
